<?php 
if (!defined('_PS_VERSION_'))
	exit;

class AffilBox extends Module
{

	// Used to build the required output for display Configuration form in the Back Office.
	private $_html = '';

	// Used to store error during validation followed by display it to user.
	private $_postErrors = array();

	public function __construct()
	{
		$version_mask = explode('.', _PS_VERSION_, 3);
		$version_test = $version_mask[0] > 0 && $version_mask[1] > 3;
		$this->name = 'affilbox';
		$this->tab = $version_test ? 'advertising_marketing' : 'CUPtech modules';
		if ($version_test) {
			$this->author = 'CUPtech s.r.o.';
		}

		$this->version = '1.0';
		$this->need_instance = 0;

		parent::__construct();

		$this->displayName = $this->l('AffilBox');
		$this->description = $this->l('Adds tracking code to each page');

		// When the module is installed, check settings
		if (self::isInstalled($this->name))
		{
			$warning = array();
			// These warnings will appear on the page where the modules are listed
			if (!Configuration::get($this->name.'_trackingcode')) {
				$warning[] .= $this->l('Tracking code');
			}
			if (!Configuration::get($this->name.'_conversioncode')) {
				$warning[] .= $this->l('Conversion code');
			}
			// $this->warning will be displayed as Warning at Modules page
			if (count($warning)) {
				$this->warning .= implode(', ', $warning).' '.$this->l('must be configured');
			}
		}
	}

	/*
	 ** Install Method
	*/
	public function install()
	{
		// install and register module to hooks
		if
		(
				parent::install() == false
				OR $this->registerHook('header') == false
				OR $this->registerHook('home') == false
				OR $this->registerHook('orderConfirmation') == false
				OR Configuration::updateValue($this->name.'_conversioncode', "", true) == false
				OR Configuration::updateValue($this->name.'_trackingcode', "", true) == false
		)
			return false;
		return true;
	}

	/*
	 ** Uninstall Method
	*/
	public function uninstall()
	{
		// Uninstall and unregister module from hooks
		if (
				parent::uninstall() == false
				OR $this->unregisterHook('header') == false
				OR $this->unregisterHook('home') == false
				OR $this->unregisterHook('orderConfirmation') == false
				OR Configuration::deleteByName($this->name.'_conversioncode') == false
				OR Configuration::deleteByName($this->name.'_trackingcode') == false
		)
			return false;
		return true;
	}

	/**
	 ** CONFIGURATION INTERFACE
	 */

	/*
	 ** Display settings form content
	*/
	public function getContent()
	{
		if (Tools::isSubmit('submit'))
		{
			//$this->_postValidation();
			if (sizeof($this->_postErrors) == 0)
			{
				$this->_postProcess();
			}
				
			if (sizeof($this->_postErrors) != 0) {
				foreach ($this->_postErrors AS $err)
				{
					$this->_html .= '<div class="alert error">'.$err.'</div>';
				}
			}
		}
		$this->_displayForm();
		return $this->_html;
	}

	/**
	 ** Validate configuration form values
	 */
	private function _postValidation()
	{
		if (!preg_match("/^<script src\b[^>]*><\/script>.{1,2}<script\b[^>]*>.*<\/script>$/s",Tools::getValue('trackingcode'))) {
			$this->_postErrors[] = $this->l('Tracking code').' '.$this->l('is not valid, please copy it exactly how it is in AffilBox administration');
		}
		if (!preg_match("/^<iframe\b[^>]*CENA\b[^>]*ID_TRANSAKCE\b[^>]*><\/iframe>$/",Tools::getValue('conversioncode'))) {
			$this->_postErrors[] = $this->l('Conversion code').' '.$this->l('is not valid, please copy it exactly how it is in AffilBox administration');
		}
	}

	/**
	 ** Function is invoked when no validation errors are present
	 */
	private function _postProcess()
	{
		Configuration::updateValue($this->name.'_trackingcode', Tools::getValue('trackingcode'), true);
		Configuration::updateValue($this->name.'_conversioncode', Tools::getValue('conversioncode'), true);
		$this->_html .= '<div class="conf confirm">'.$this->l('Settings updated').'</div>';
	}

	private function _displayForm()
	{
		$this->_html .= '<form action="'.Tools::htmlentitiesUTF8($_SERVER['REQUEST_URI']).'" method="post">';
		$this->_html .= '<fieldset>';
		$this->_html .= '<legend>'.$this->l('Settings').'</legend>';
		
		$this->_html .= '<label>'.$this->l('Tracking code').'</label>';
		$this->_html .= '<div class="margin-form">';
		$this->_html .= '<textarea rows="6" cols="100" name="trackingcode" >'.Tools::htmlentitiesUTF8(Tools::getValue('trackingcode', Configuration::get($this->name.'_trackingcode'))).'</textarea>';
		$this->_html .= '</div>';
		
		$this->_html .= '<label>'.$this->l('Conversion code').'</label>';
		$this->_html .= '<div class="margin-form">';
		$this->_html .= '<textarea rows="6" cols="100" name="conversioncode" >'.Tools::htmlentitiesUTF8(Tools::getValue('conversioncode', Configuration::get($this->name.'_conversioncode'))).'</textarea>';
		$this->_html .= '</div>';

		$this->_html .= '<input type="submit" name="submit" value="'.$this->l('Update').'" class="button" />';
		$this->_html .= '</fieldset>';
		$this->_html .= '</form>';
	}
	
	
	/*
	 ** HOOKS IMPLEMENTATION
	*/

	/**
	 ** HOOK_HEADER is invoked in <header> section of HTML document.
	 */
	public function hookHeader()
	{
		return Configuration::get($this->name.'_trackingcode');
	}

	/**
	 ** HOOK_ORDER_CONFIRMATION is invoked after completing order
	 */
	public function hookOrderConfirmation($params)
	{
		$orderId = $params['order']->id;
		$orderTotal = $params['order']->total_products;
		$conversioncode = Configuration::get($this->name.'_conversioncode');
		$conversioncode = str_replace("= CENA", "= ".$orderTotal, $conversioncode);
		$conversioncode = str_replace("ID_TRANSAKCE", $orderId, $conversioncode);
		return $conversioncode;
	}

	/**
	 ** Gets id of last order done by customer, returns false if no order present
	 */
	private function getLastOrder($id_customer)
	{
		$result = Db::getInstance()->getRow('
				SELECT MAX(o.`id_order`) AS id_order
				FROM `'._DB_PREFIX_.'orders` o
				WHERE o.`id_customer` = '.(int)($id_customer));
		if (isset($result['id_order']))
			return $result['id_order'];
		return false;
	}

	/**
	 ** Generates conversion code for GoPay
	 */
	public function hookHome($params)
	{
		if(isset($_GET['paymentState']) && $_GET['paymentState'] == 'done'){
			global $cookie;
			$id_order = $this->getLastOrder($cookie->id_customer);
			if($id_order){
				$order = new Order($id_order);
				$params = Array('objOrder' => $order);
				return $this->hookOrderConfirmation($params);
			}
		}
	}
}
